@@ -246,7 +246,7 @@ channels_detailed =  ['acu.message_counter',
  'acu.safety_controller.safety_status_bs.safety_system_error',
  'acu.safety_controller.safety_status_bs.safety_system_run',
  'acu.safety_controller.safety_status_bs.door_switch_status_ped',
- 'acu.safety_controller.safety_status_bs.door_switch_status_psc',
+#  'acu.safety_controller.safety_status_bs.door_switch_status_psc',
  'acu.safety_controller.safety_status_bs.lockout_azimuth',
  'acu.safety_controller.safety_status_bs.lockout_elevation',
  'acu.safety_controller.safety_status_bs.lockout_feedindexer',
@@ -604,3 +604,6 @@ channels_hn_tilt_sensors=[
 'acu.pointing.incl_corr_val_el'
 ]
 
+if __name__ == "__main__":
+    for l in channels_detailed:
+        print(l)
\ No newline at end of file
