@@ -172,7 +172,9 @@ class Telescope():
         self.noise_level = 0.005 # -> results in ~5" on az and 10" on el
 
         last_session = int(astropy.time.Time.now().unix) - 1629728852
-        self.data = { "acu.time.internal_time": self.t_internal.mjd,
+        self.data = { 
+                "acu.time.external_ptp" : self.t_internal.mjd,
+                "acu.time.internal_time": self.t_internal.mjd,
                 "acu.azimuth.p_act": 90.,
                 "acu.azimuth.p_set": 90.,
                 "acu.azimuth.p_shape": 90,
@@ -230,7 +232,51 @@ class Telescope():
                 "acu.pointing.p21": 0,
                 "acu.pointing.p22": 0,
                 "acu.pointing.p23": 0,
-                "acu.pointing.p24": 0
+                "acu.pointing.p24": 0,
+
+                'acu.general_management_and_controller.temp_azimuth_i_o_unit': -273.15,
+                'acu.general_management_and_controller.temp_elevation_i_o_unit': -273.15,
+                'acu.general_management_and_controller.temp_feedindexer_i_o_unit': -273.15,
+                'acu.general_management_and_controller.temp_emisc': -273.15,
+                'acu.general_management_and_controller.temp_drive_cab': -273.15,
+                'acu.general_management_and_controller.temp_air_inlet_psc': -273.15,
+                'acu.general_management_and_controller.temp_air_outlet_psc': -273.15,
+                'acu.azimuth.motor_1.motor_temperature': -273.15,
+                'acu.azimuth.motor_2.motor_temperature': -273.15,
+                'acu.elevation.motor_1.motor_temperature': -273.15,
+                'acu.elevation.motor_2.motor_temperature': -273.15,
+                'acu.feed_indexer.motor_1.motor_temperature': -273.15,
+                'acu.feed_indexer.motor_2.motor_temperature': -273.15,
+                'acu.pointing.pointing_status.point_amb_temp_corr_enabled': -273.15,
+                'acu.pointing.act_amb_temp_1': -273.15,
+                'acu.pointing.act_amb_temp_2': -273.15,
+                'acu.pointing.act_amb_temp_3': -273.15,
+                'acu.pointing.amb_temp_corr_val_az': -273.15,
+                'acu.pointing.amb_temp_corr_val_el': -273.15,
+                'acu.pointing.amb_temp_corr_filter_constant': -273.15,
+                'acu.pointing.incl_temp': -273.15,
+
+                'acu.safety_controller.safety_status_bs.safety_system_error': False,
+                'acu.safety_controller.safety_status_bs.lockout_azimuth': False,
+                'acu.safety_controller.safety_status_bs.lockout_elevation': False,
+                'acu.safety_controller.safety_status_bs.lockout_feedindexer': False,
+
+                'acu.safety_controller.safety_status_bs.interlock_hatch': False,
+                'acu.safety_controller.safety_status_bs.e_stop_hhd_junction_box': False,
+                'acu.feed_indexer.axis_bit_status.abs_emergency_stop': False,
+                'acu.elevation.axis_bit_status.abs_emergency_stop': False,
+                'acu.azimuth.axis_bit_status.abs_emergency_stop': False,
+
+
+                'acu.azimuth.error_status.err_error_active': False,
+                'acu.elevation.error_status.err_error_active': False,
+                'acu.feed_indexer.error_status.err_error_active': False,
+
+                'acu.general_management_and_controller.warning_status.door_ped_open_warning': False,
+                'acu.general_management_and_controller.warning_status.door_psc_open_warning': False,
+                'acu.general_management_and_controller.warning_status.door_sc_open_warning': False,
+                'acu.general_management_and_controller.warning_status.door_d_open_warning': False,
+                'acu.general_management_and_controller.warning_status.hatch_el_open_warning': False,
                 }
 
         self.datalog = {last_session: []}
