@@ -12,6 +12,7 @@
 
 
 #Import of Python available libraries
+import uuid
 import numpy as np
 import json
 import pandas as pd
@@ -70,6 +71,12 @@ import astropy
 
 import datetime
 
+import os, inspect, sys
+current_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+parent_dir = os.path.dirname(current_dir)
+if __name__ == '__main__':
+    sys.path.insert(0, parent_dir)
+
 from mke_sculib.mock_telescope import Telescope
 import mke_sculib.scu as scu
 from mke_sculib.scu import log
@@ -100,30 +107,37 @@ def get_routes(telescope: Telescope) -> dict:
 
 
 class MockRequest():
-    def __init__(self, url, body) -> None:
+    def __init__(self, method, url, body) -> None:
         self.url = url
         self.body = body
-
+        self.method = method
 
 class MockResponseObject():
-    def __init__(self, url, status_code:int, content) -> None:
+    def __init__(self, method, url, status_code:int, content, with_uuid = False) -> None:
         self.status_code = status_code
         self._content = content
         self.reason = 'I am a teapod!'
-        self.request = MockRequest(url, content)
+        self.request = MockRequest(method, url, content)
+        self.uuid = str(uuid.uuid4()) if with_uuid else ''
 
     def json(self):
+        if isinstance(self._content, dict) and self.uuid:
+            res = {'uuid': self.uuid}.update(self._content)
+            return res 
         if not isinstance(self._content, str):
             return self._content
         else:
-            return json.loads(self._content)
+            res = json.loads(self._content)
+            if self.uuid and isinstance(res, dict):
+                res.update({'uuid': self.uuid})
+            return res
 
     @property
     def text(self):
         return str(self._content)
 
 
-
+@scu.aliased
 class scu_sim(scu.scu):
     """A SCU SIMULATOR object, which SIMULATES a connection to a real SCU controller by OHB 
     Digital Connect GmbH for the SKA-MPI Demonstrator Radio Telescope in the Karroo Desert 
@@ -137,7 +151,7 @@ class scu_sim(scu.scu):
 
     (This class inherits from a real SCU interface object and overwrites the communication channels)
     """
-    def __init__(self, address='', ip='', port='8080', use_realtime=False, debug=True, speedup_factor=1, t_start = astropy.time.Time.now(), UPDATE_INTERVAL = .1, lims_az=(-270.0, 270, 3.0), lims_el=(15, 90, 1.35), dish_type='mke', post_put_delay=0.0, **kwargs):
+    def __init__(self, address='', ip='', port='8080', use_realtime=False, debug=True, speedup_factor=1, t_start = astropy.time.Time.now(), UPDATE_INTERVAL = .1, lims_az=(-270.0, 270, 3.0), lims_el=(15, 90, 1.35), dish_type='mke', post_put_delay=0.0, antenna_dc=None, **kwargs):
         """create an antenna scu/acu simulator object, which can be used to simulate the motion of
         a real Antenna in simulation time (ahead of time) in order to debug test scripts etc.
 
@@ -168,8 +182,33 @@ class scu_sim(scu.scu):
         self.routes = get_routes(self.telescope)
 
 
-        scu.scu.__init__(self, address=address, ip=ip, port=port, debug=debug, lims_az=lims_az, lims_el=lims_el, dish_type=dish_type, post_put_delay=post_put_delay, use_socket=False)
+        scu.scu.__init__(self, debug=debug, lims_az=lims_az, lims_el=lims_el, dish_type=dish_type, post_put_delay=post_put_delay, use_socket=False, wait_done_by_uuid=False, antenna_dc=antenna_dc, **kwargs)
     
+    def __str__(self):
+        antenna_id = f' with antenna_id: "{self.antenna_id}"' if self.antenna_id else ''        
+        use_realtime = 'YES' if self.telescope.use_realtime else 'NO'
+        return f'scu_sim object{antenna_id} @SIMULATOR, dish_type: "{self.dish_type}" realtime?:{use_realtime}'
+
+    def __repr__(self):
+        return str(self)
+    
+    @property
+    def address(self):
+        """address of the dish as: http://IP:PORT"""
+        return f'SIMULATOR'
+    
+    @property
+    def version_acu(self):
+        rt = '_rt' if self.telescope.use_realtime else ''
+        return 'sim' + rt
+
+    @property
+    def event_streamer(self):
+        return None
+
+    @event_streamer.setter
+    def event_streamer(self, value):
+        pass
 
     @property
     def data_streamer(self):
@@ -179,6 +218,14 @@ class scu_sim(scu.scu):
     def data_streamer(self, value):
         pass
 
+    @property
+    def wait_done_by_uuid(self):
+        return None
+    
+    @wait_done_by_uuid.setter
+    def wait_done_by_uuid(self, value):
+        pass
+
     @property
     def use_socket(self):
         return None
@@ -191,7 +238,7 @@ class scu_sim(scu.scu):
     def data(self):
         return self.telescope.data
 
-    def getc(self, key, as_dict=False):
+    def getc(self, key=None, as_dict=False):
         """get one or many channel values. key(s) must be string or list of strings
 
         Args:
@@ -207,12 +254,12 @@ class scu_sim(scu.scu):
                 else:
                     return self.get_many(channels=key, as_dict=as_dict)
         except Exception as err:
-            log(f'error while getting data from socket stream... falling back to HTTP api. {err=}', color=colors.WARNING)
+            log(f'error while getting data from socket stream... falling back to HTTP api. {err=}', color=scu.colors.WARNING)
 
         if key is None:
             return dict(self.get_channel_list(with_values=True, with_timestamps=False))
-        elif not isinstance(key, str) and hasattr(self, '__len__'):
-            allchans = self.data
+        elif not isinstance(key, str) and hasattr(key, '__len__'):
+            allchans = {**{k:None for k in key}, **self.data}
             if as_dict:
                 return {k:allchans[k] for k in key}
             else:
@@ -251,34 +298,37 @@ class scu_sim(scu.scu):
             self.call_log[self.telescope.t_internal.datetime] = 'GET | ' + device
 
         if device not in self.routes['GET']:
-            r = MockResponseObject(URL, 404, {})
+            r = MockResponseObject('GET', URL, 404, {})
         else:
             fun = self.routes['GET'][device]
             res = fun(params)
-            r = MockResponseObject(URL, res['status'], res['body'])
+            r = MockResponseObject('GET', URL, res['status'], res['body'])
 
         self._feedback(r)
 
         return(r)
 
-    def scu_put(self, device, payload = {}, params = {}, data=''):
+    def scu_put(self, device, payload = {}, params = {}, data='', get_uuid=True):
         '''This is a generic PUT command into http: scu port + folder 
         with json=payload (OVERWRITTEN FOR SIMULATION!)'''
         URL = 'http://' + self.ip + ':' + self.port + device
         self.call_log[self.telescope.t_internal.datetime] = 'PUT | ' + device
         if device not in self.routes['PUT']:
-            r = MockResponseObject(URL, 404, {})
+            r = MockResponseObject('PUT', URL, 404, {}, with_uuid=get_uuid)
         else:
             fun = self.routes['PUT'][device]
             res = fun(payload, params, data)
-            r = MockResponseObject(URL, res['status'], res['body'])
-        self._feedback(r)
+            r = MockResponseObject('PUT', URL, res['status'], res['body'], with_uuid=get_uuid)
+        self._feedback(r, get_uuid=False)
         
         if self.post_put_delay > 0:
             self.wait_duration(self.post_put_delay, no_stout=True)
         
-        return(r)
-
+        return r.uuid
+    
+    def ping(self, *args, **kwargs):
+        return f'I AM A SIMULATOR! {self}'
+    
     def scu_delete(self, device, payload = {}, params = {}):
         '''This is a generic DELETE command into http: scu port + folder 
         with params=payload (OVERWRITTEN FOR SIMULATION!)'''
@@ -292,6 +342,7 @@ class scu_sim(scu.scu):
         print(*args, **kwargs)
 
     #wait seconds, wait value, wait finalValue
+    @scu.alias('sleep', 'wait')
     def wait_duration(self, seconds, no_stout=False):
         """have the simulator wait for a given amount of seconds (but script will continue)
 
@@ -367,6 +418,9 @@ class scu_sim(scu.scu):
         df.index = pd.to_datetime(df.index, errors='coerce')
         return df
 
+    def get_band_in_focus(self, as_name=False):
+        band_str = self.getc('acu.general_management_and_controller.feed_indexer_pos')
+        return band_str if as_name else scu.bands_dc.get(band_str, -1)
 
     def start(self, az_start=None, el_start=None, band_start=None, az_speed=3, el_speed=1, send_default_configs=True):
         """getting command authority, unstow, activate and start the antenna for usage
@@ -578,8 +632,7 @@ def plot_motion_pyplot(df, xkey='index', figsize=(12, 10), df_tt=None, event_log
 
 
 if __name__ == '__main__':
-   print("main")
-
-        
-        
-        
+    print("main")
+    dish = scu_sim()
+    print(dish.ping())
+    print(dish.sleep(10))
\ No newline at end of file
